About
-------------------------------
WORK IN PROGRES - Declarative service-oriented approach with hooks for using Fabric to provision a machine or vagrant box.

The services are currently set to be configured for running Django. They may or may not provide a configuration you want.

Supported Services
-------------------------------

* cron
* geoip
* memcached
* mysql
* nginx
* postgresql
* redis
* s3
* supervisor
* uwsgi

Extras
-------------------------------

* Generate signed S3 upload policy to submit files to S3 directly from JavaScript.

License
-------------------------------
MIT
